==> dvdisaster-0.72.3.tar.bz2: dvdisaster-0.72.3/documentation/de/privacy.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<b>Datenschutzerklärung für die Internetangebote unter</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

Das dvdisaster-Projekt (<a href="imprint.php">Anbieter siehe Impressum</a>)
nimmt den Schutz personenbezogener Daten sehr ernst.
Die nachfolgende Erklärung gibt Ihnen einen Überblick darüber,
welche Daten zu welchem Zweck erhoben werden:

<p>

<b>Protokoll-Dateien</b> (Datenverarbeitung durch die Server dieser Internetseiten)<p>

Ihr Besuch dieses Internetangebotes wird protokolliert. 
Die Server dieser Internetseiten speichern die folgenden Daten:

<ul>
<li>den Typ und die Version Ihres Browsers</li>
<li>das verwendete Betriebssystem</li>
<li>gegebenenfalls die Webseite, von der aus Sie zu diesem Internetangebot gelangt sind</li>
<li>den Hostnamen oder die IP-Adresse des zugreifenden Rechners</li>
<li>die Uhrzeit und das Datum der Serveranfrage</li>
<li>die Dateinamen der angefragten Seiten.</li>
</ul>

Diese Daten werden weder dazu genutzt, den Besucher dieser Webseiten
zu identifizieren, noch findet eine Zusammenführung mit anderen Daten
statt. Die Daten werden nach einer statistischen Auswertung gelöscht.

<p>

<b>Cookies</b><p>

Dieses Internetangebot verwendet keine Cookies.

<p>

<b>Links zu anderen Webseiten</b><p>

Dieses Internetangebot enthält Links zu anderen Webseiten. 
Das dvdisaster-Projekt hat keinen Einfluß darauf, 
ob deren Anbieter diese Datenschutzbestimmungen einhalten.

<p>

<b>Weiterentwicklung dieser Internetseiten</b><p>

Im Zuge der Weiterentwicklung dieser Internetseiten können Änderungen
dieser Datenschutzerklärung erforderlich werden. Bitte lesen Sie sich
diese Datenschutzerklärung von Zeit zu Zeit erneut durch.

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/de/privacy.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<b>Datenschutzerklärung für die Internetangebote unter</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

Das dvdisaster-Projekt (<a href="imprint.php">Anbieter siehe Impressum</a>)
nimmt den Schutz personenbezogener Daten sehr ernst.
Die nachfolgende Erklärung gibt Ihnen einen Überblick darüber,
welche Daten zu welchem Zweck erhoben werden:

<p>

<b>Protokoll-Dateien</b> (Datenverarbeitung durch die Server dieser Internetseiten)<p>

Ihr Besuch dieses Internetangebotes wird protokolliert. 
Die Server dieser Internetseiten speichern die folgenden Daten:

<ul>
<li>den Typ und die Version Ihres Browsers</li>
<li>das verwendete Betriebssystem</li>
<li>gegebenenfalls die Webseite, von der aus Sie zu diesem Internetangebot gelangt sind</li>
<li>den Hostnamen oder die IP-Adresse des zugreifenden Rechners</li>
<li>die Uhrzeit und das Datum der Serveranfrage</li>
<li>die Dateinamen der angefragten Seiten.</li>
</ul>

Diese Daten werden weder dazu genutzt, den Besucher dieser Webseiten
zu identifizieren, noch findet eine Zusammenführung mit anderen Daten
statt. Die Daten werden nach einer statistischen Auswertung gelöscht.

<p>

<b>Cookies</b><p>

Dieses Internetangebot verwendet keine Cookies.

<p>

<b>Links zu anderen Webseiten</b><p>

Dieses Internetangebot enthält Links zu anderen Webseiten. 
Das dvdisaster-Projekt hat keinen Einfluß darauf, 
ob deren Anbieter diese Datenschutzbestimmungen einhalten.

<p>

<b>Weiterentwicklung dieser Internetseiten</b><p>

Im Zuge der Weiterentwicklung dieser Internetseiten können Änderungen
dieser Datenschutzerklärung erforderlich werden. Bitte lesen Sie sich
diese Datenschutzerklärung von Zeit zu Zeit erneut durch.

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
